@@ -356,8 +356,8 @@ class readSam(object):
             read_name_r1 = line_r1[0]
             read_name_r2 = line_r2[0]
             if read_name_r1 != read_name_r2:
-                self._mut_log.info(read_name_r1)
-                self._mut_log.info(read_name_r2)
+                print(read_name_r1)
+                print(read_name_r2)
                 self._mut_log.error("Read pair IDs did not map, please check fastq files")
                 raise  ValueError("Read pair IDs did not map, please check fastq files")
 
